%%%%%%
% MCS REPORT CLASS FOR HONOURS, MASTERS and PHD STYLE REPORTS.
%	 -- modified from vuwstyle
%        -- initially released 3 October 1991
%
% Sets up cover page and page size for VUW CS honours, masters
% and phd reports.
%
% Modifications:
%   by Tristan Faber. November 29th 2005
%    * added book option
%    * (re-)allowed choice of font size
%    * added compact option to allow paper saving format (only for twoside option)
%    * added option to choose subject: comp, maths, amaths, stats
%   by Mike McGavin to LaTeX class. September 24th 2003.
%    * Conversion from package to class. (report/article now via option)
%    * Now option to decide between honours, msc and phd.
%   by Andrew Mellanby to allow for 2 supervisors (Job number 10774)
%   by Ewan Tempero for the new TR cover. October 1993.
%
% INSTRUCTIONS:
%
% Works with both article and report style
%
% When using class, specify either [report] or [article] option.
%       (Defaults to report.)
%
% Specify exactly one of [honours], [msc] or [phd].
%
% Font size options (10pt, 11pt and 12pt) are ignored, but all other
% options are passed to either report or article class.
%
% Use \title{} to specify title, \author{} to specify author,
%	\supervisor{} or \supervisors to specify supervisor(s),
%       \date{} to specify date, and ``abstract'' environment
%       for abstract. 
%
% Use \maketitle AFTER everything has been specified.
%
%%%%%%


\NeedsTeXFormat{LaTeX2e}[1994/06/01]
\ProvidesClass {mcsthesis}[2003/09/24 v0.5 Experimental MCS class for thesis and thesis-like reports]

\RequirePackage{ifthen}[1994/06/01]
\RequirePackage{setspace}

% Make a command called \setdegree to set the type of degree,
% but bail out with an error if it's already been set.
\gdef\@setdegree#1#2{
  \ifthenelse{\equal{\degree}{unspecified}}{
    \renewcommand{\degree}{#1}
    \renewcommand{\degreetext}{#2}
  }{
    % Oops, two degree options have been specified.
    \ClassError{mcsthesis}{
      You can only specify one of 'honours', 'msc' or 'phd'.
    }{
      Please adjust the options of your source document so that only
      one of 'honours', 'msc' or 'phd' is specified.
    }
  }

}

%% disabled by Tristan 2005
%\gdef\@fontwarning#1{
%  \ClassWarning{mcsthesis}{
%    Please note that the font size is being forced to 11pt,
%    even though you specified #1.
%  }
%}

% Init the degree command to unspecified, then set it to whatever the options say.
\newcommand{\degree}{unspecified}
\newcommand{\degreetext}{unspecified}
\newcommand{\thesisfontsize}{unspecified}
\newcommand{\degreesubject}{UNSPECFIED SUBJECT (options comp, maths, amaths, stats)}
\newboolean{isdraft}
\newboolean{isreport}
\newboolean{isbook}
\setboolean{isdraft}{false}
\setboolean{isreport}{false}

\newcommand{\optlinespacing}{1.0}
\newcommand{\optoddsidemargin}{0mm}
\newcommand{\optevensidemargin}{-3.6mm}
\newcommand{\opttextwidth}{155mm}
\newcommand{\opttextheight}{240mm}
\newcommand{\opttopmargin}{-8.2mm}

% Catch subject option
\DeclareOption{comp}{\renewcommand{\degreesubject}{Computer Science}}
\DeclareOption{maths}{\renewcommand{\degreesubject}{Mathematics}}
\DeclareOption{amaths}{\renewcommand{\degreesubject}{Applied Mathematics}}
\DeclareOption{stats}{\renewcommand{\degreesubject}{Statistics}}


% Catch degree option
\DeclareOption{honours}{\@setdegree{\CurrentOption}{
    Submitted to Victoria University of Wellington \\
    in partial fulfilment of the requirements for the degree of \\
    Bachelor of Science with Honours in \degreesubject.
  }
}
\DeclareOption{msc}{\@setdegree{\CurrentOption}{
    Submitted to Victoria University of Wellington \\
    in fulfilment of the requirements for the degree of \\
    Master of Science in \degreesubject.
  }
}
\DeclareOption{phd}{\@setdegree{\CurrentOption}{
    Submitted to Victoria University of Wellington \\
    in fulfilment of the requirements for the degree of \\
    Doctor of Philosophy in \degreesubject.
  }
}

% Catch article, report and book options, to determine if an article
% or report is wanted.
\DeclareOption{report}{ \setboolean{isreport}{true}}
\DeclareOption{article}{\setboolean{isreport}{false}}
\DeclareOption{book}{   \setboolean{isreport}{false}\setboolean{isbook}{true}}

% Check whether there has been a userdefined fontsize
\DeclareOption{10pt}{\renewcommand{\thesisfontsize}{10pt}}
\DeclareOption{11pt}{\renewcommand{\thesisfontsize}{11pt}}
\DeclareOption{12pt}{\renewcommand{\thesisfontsize}{12pt}}

% Catch draft option
\DeclareOption{compact}{\setboolean{isdraft}{true}}

% Pass remaining options to the report class underneath, then process things.
\DeclareOption*{
  \PassOptionsToClass{\CurrentOption}{report}
  \PassOptionsToClass{\CurrentOption}{article}
  \PassOptionsToClass{\CurrentOption}{book}
}
\ProcessOptions\relax


% Set parameters for draft mode
\ifthenelse{\boolean{isdraft}}{
  \ifthenelse{\equal{\thesisfontsize}{unspecified}}{
    \renewcommand{\thesisfontsize}{11pt}
  }{}
  \renewcommand{\optlinespacing}{1.0}
  \renewcommand{\optoddsidemargin}{0mm}
  \renewcommand{\optevensidemargin}{-3.6mm}
  \renewcommand{\opttextwidth}{155mm}
  \renewcommand{\opttextheight}{240mm}
  \renewcommand{\opttopmargin}{-8.2mm}
}{ % set parameters for non-draft mode (conform to library requirements)
  \ifthenelse{\equal{\thesisfontsize}{unspecified}}{
    \renewcommand{\thesisfontsize}{12pt}
  }{}
  \renewcommand{\optlinespacing}{1.5}
  \renewcommand{\optoddsidemargin}{15mm}
  \renewcommand{\optevensidemargin}{-0.4mm}
  \renewcommand{\opttextwidth}{145mm}
  \renewcommand{\opttextheight}{235mm}
  \renewcommand{\opttopmargin}{-5.4mm}
}



% Make sure a style of thesis was specified, and bail out if it wasn't.
\ifthenelse{\equal{\degree}{unspecified}}{
  \ClassError{mscreport}{
    You didn't specify a thesis-style option. (Either 'honours', 'msc' or 'phd'.)
  }{
    Please specify either 'honours', 'msc' or 'phd' as an option for your report style.
  }
}{
}

% Load either the report or article class, depending on option.
% Force 11pt.
\ifthenelse{\boolean{isreport}}{
  % Report specified (or defaulted) so load as a report.
  \LoadClass[\thesisfontsize]{report}
}{
  \ifthenelse{\boolean{isbook}}{
    % Book specified so load as a book.
    \LoadClass[\thesisfontsize]{book}
  }{
    % Report and book not specified, so load as an article.
    \LoadClass[\thesisfontsize]{article}
  }
}

%%%
% Now commence Operation Format Report ...
% Most of the following code was taken from the vuwhonours.sty
% package, and modified to work more nicely as a class.
%%%

% NOTE: The following definition requires the font "vuw20". If this class
% is to be compiled on a non-VUW system, the font won't be available by default.
\font\vuwf  = vuw20 scaled\magstep4
\font\pal = pplr scaled 2000
\font\pali = pplri scaled 2000
\font\bigpal = pplr scaled 2820
\def\t@s{\kern 1.4pt}
\def\t@t{\kern 0.4pt}

\if@twoside
   \oddsidemargin\optoddsidemargin \evensidemargin\optevensidemargin \marginparwidth 20mm
\else
   \oddsidemargin 2mm \evensidemargin 4.4mm \marginparwidth 20mm
\fi
\marginparsep 2.5mm

\topmargin\opttopmargin \headheight 12pt \headsep 25pt \footskip 30pt

\textheight\opttextheight \textwidth\opttextwidth \columnsep 10pt \columnseprule 0pt

\def\supervisor#1{\gdef\@supervisor{Supervisor: #1}}
\def\supervisors#1{\gdef\@supervisor{Supervisors: #1}}
\gdef\@supervisor{Supervisor: NOT STATED}


\def\maketitle{\begin{titlepage}
{\renewcommand{\baselinestretch}{1.0}

\thispagestyle{empty}
 \let\footnotesize\small
 \let\footnoterule\relax
 \if@twoside\setcounter{page}{-1}\else\setcounter{page}{0}\fi
 \null

\begin{center}
{\pal V\t@s I\t@s C\t@s T\t@s O\t@s R\t@s I\t@s A\  \t@s
U\t@s N\t@s I\t@s V\t@s E\t@s R\t@s S\t@s I\t@s T\t@s Y\ \t@s O\t@s F\ \t@s 
W\t@s E\t@s L\t@s L\t@s I\t@s N\t@s G\t@s T\t@s O\t@s N}\\*[3pt]
{\pali T\t@t e\  W\t@t h\t@t a\t@t r\t@t e\  W\t@t
a\t@t n\t@t a\t@t n\t@t g\t@t a\  o\  t\t@t e\  U\t@t p\t@t o\t@t 
k\t@t o\  o\  t\t@t e\  I\t@t k\t@t a\  a\  M\t@t a\t@t
u\t@t i}\\*[8pt]
{\vuwf VUW}\\*[8pt]
{\bigpal School of Mathematics, Statistics \\*[8pt] and Computer Science}
%{\bigpal Computer Science}
\end{center}

\vspace*{-2mm}
\noindent
\hspace*{3mm}
{\small
\parbox{40mm}{
PO Box 600\\
Wellington\\
New Zealand}\hfill
\parbox{65mm}{
\flushright
Tel: 	+64 4 463 5341\\
Fax:	+64 4 463 5045\\
Internet: office@mcs.vuw.ac.nz}
}
\parbox{3mm}{\mbox{}}

%\vspace*{2mm}

 \begin{center}
  \parbox{100mm}{\center\LARGE\bf\@title}\par
  \vskip 1em
  \parbox{100mm}{\center\large\@author}\par
  \vskip 1em
  \parbox{100mm}{\center\large \@supervisor}\par
  \vskip 1em
  {\large \@date \par}
  \vskip 1em
  \parbox{100mm}{\center \degreetext}\par
\end{center} \par
\@thanks
} %end baselinestretch 1.0

\newpage
%\vskip 1em
~\vspace{10mm}
\begin{center}
{\bf \Large Abstract}%\vspace{-.5em}\vspace{0pt}}
\end{center}
\bigskip\bigskip
%\vskip 1ex
\hskip\leftmargini\box\@abstract
\vfill

\newpage
\end{titlepage}

\setcounter{footnote}{0}
\if@twoside\setcounter{page}{1}\fi
\let\thanks\relax
\gdef\@thanks{}\gdef\@author{}\gdef\@title{}\let\maketitle\relax}


\newbox\@abstract
\def\abstract{\global\setbox\@abstract\vbox\bgroup
   \advance\linewidth 0\leftmargini
   \hsize\linewidth}

\def\endabstract{\egroup}

\ifthenelse{\equal{\optlinespacing}{1.0}}{
  \singlespace
}{
  \onehalfspace
}
%\renewcommand{\baselinestretch}{\optlinespacing}